@@ -2,6 +2,6 @@ from .prompts import Choice as Choice
 from .prompts import BasePrompt as BasePrompt
 from .prompts import ListPrompt as ListPrompt
 from .prompts import InputPrompt as InputPrompt
-from .prompts import CanceledError as CanceledError
 from .prompts import ConfirmPrompt as ConfirmPrompt
+from .prompts import CancelledError as CancelledError
 from .prompts import CheckboxPrompt as CheckboxPrompt
