@@ -11,6 +11,33 @@ from ._options import (
     question_mark_style_option,
 )
 
+
+def input_prompt_main(
+    question: str,
+    default_text: Optional[str] = None,
+    *,
+    no_ansi: bool = False,
+    default: Optional[str] = None,
+    question_style: Optional[str] = None,
+    question_mark: Optional[str] = None,
+    question_mark_style: Optional[str] = None,
+    answer_style: Optional[str] = None,
+    **kwargs,
+):
+    prompt = InputPrompt(
+        question, default_text=default_text, question_mark=question_mark
+    )
+    prompt.prompt(
+        default=default,
+        no_ansi=no_ansi,
+        style=build_style(
+            question=question_style,
+            questionmark=question_mark_style,
+            answer=answer_style,
+        ),
+    )
+
+
 input_prompt = subparsers.add_parser(
     "input",
     description="Input prompt.",
@@ -21,27 +48,11 @@ input_prompt = subparsers.add_parser(
         answer_style_option,
     ],
 )
+input_prompt.add_argument(
+    "-d",
+    "--default-text",
+    required=False,
+    help="default text",
+)
 input_prompt.add_argument("question", help="prompt question")
-
-
-def input_prompt_main(
-    question: str,
-    *,
-    no_ansi: bool = False,
-    default: Optional[str] = None,
-    question_style: Optional[str] = None,
-    question_mark: Optional[str] = None,
-    question_mark_style: Optional[str] = None,
-    answer_style: Optional[str] = None,
-    **kwargs,
-):
-    prompt = InputPrompt(question, question_mark=question_mark)
-    prompt.prompt(
-        default=default,
-        no_ansi=no_ansi,
-        style=build_style(
-            question=question_style,
-            questionmark=question_mark_style,
-            answer=answer_style,
-        ),
-    )
+input_prompt.set_defaults(func=input_prompt_main)
